==> haskell-http-client-tls-0.3.6.4-102-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
key:                  http-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  64a165bdf73ff36dc6b36e067fe79935
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-8Rtb2QgRnuG7Z2EdKrVOdn
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7 containers-0.6.7
    crypton-1.0.3-16cGkRi6FF0JFIvaY823Of
    crypton-connection-0.4.4-Euem0yM0Cv6LMDpPbuhAEm
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR exceptions-0.10.5
    http-client-0.7.19-LiXl0zXhncYKUDAcqgcwk8
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    network-uri-2.6.4.2-6dAHdOyJLq76CXdDmIsqEl text-2.0.2
    tls-2.0.6-IakNTBA0JiNDRPputM9FQX transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.6.4-124-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-tls
version:              0.3.6.4
visibility:           public
id:                   http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
key:                  http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:
    http-client backend using the connection package and tls library

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.

category:             Network
abi:                  3c7a5b7d886f53da141af1dcd77b2d75
exposed:              True
exposed-modules:      Network.HTTP.Client.TLS
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-tls-0.3.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.4.8/http-client-tls-0.3.6.4
hs-libraries:         HShttp-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY containers-0.6.7
    crypton-1.0.4-AGWvxb3uQebCjfbnRIxIRG
    crypton-connection-0.4.5-CBwSG29ckAMGaPodtkho7w
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi exceptions-0.10.5
    http-client-0.7.19-Iyp8kyAVyHs5ic3dfNFLTs
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-uri-2.6.4.2-DVBcu05aYxxCjTvpzOd17v text-2.0.2
    tls-2.0.6-I1Ld4heBgrMIPyOIwAkQZM transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock

haddock-html:         /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
